@@ -39,6 +39,7 @@ def set_dataframe_columntypes(df):
     if 'idLead' in df:
         df['idLead'] = df['idLead'].astype('int32')
     if 'idCampaign' in df:
+        df['idCampaign']= df['idCampaign'].astype('Int64')
         df['idCampaign'] = df['idCampaign'].apply(str)
     # if 'BulkStatus' in df:
     #     df['BulkStatus']=df['BulkStatus'].astype('str')
@@ -179,6 +180,10 @@ def set_idemailstatus_target_column(df):
     if ('IDEmailStatus' in df.columns):
         logger.info('Setting E-Mail status target ')
         df = df[~df['IDEmailStatus'].isin([3, 5, 7, 32])]
+        # C80 has an special conversion Status, setting it to 14 like the other campaigns
+        df.loc[(df['idCampaign'] == '80') &
+               (df['IDEmailStatus'] ==31),
+            'IDEmailStatus']=14
         df.loc[df['IDEmailStatus'] != 14, 'IDEmailStatus'] = 0
         df.loc[df['IDEmailStatus'] == 14, 'IDEmailStatus'] = 1
         date_col = df['campaign_bulk_date']
@@ -282,14 +287,13 @@ def create_company_years_column(df):
 
 def clean_companytype(df):
     df.loc[
-        df['Type'] != 'Educational Institution' &
-        df['Type'] != 'Government Agency' &
-        df['Type'] != 'Government Agency' &
-        df['Type'] != 'Nonprofit' &
-        df['Type'] != 'Partnership' &
-        df['Type'] != 'Privately Held' &
-        df['Type'] != 'Public Company' &
-        df['Type'] != 'Self-Employed',
+        (df['Type'] != 'Educational Institution') &
+        (df['Type'] != 'Government Agency') & 
+        (df['Type'] != 'Nonprofit') &
+        (df['Type'] != 'Partnership') &
+        (df['Type'] != 'Privately Held') &
+        (df['Type'] != 'Public Company') &
+        (df['Type'] != 'Self-Employed'),
         'Type'    ] = 'Unknown'
     return df
 
